#!/usr/bin/env python3
# uservice_logging
# Copyright (C) 2015 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import sys
assert sys.version_info >= (3,), 'Python 3 is required'

from setuptools import find_packages, setup

import uservice_logging


def get_version():
    """Return the version of uservice_logging that we are building."""
    version = '.'.join(
        str(component) for component in uservice_logging.__version__[0:3])
    phase = uservice_logging.__version__[3]
    if phase == 'final':
        return version
    # Apparently if we just say "snapshot" then distribute won't accept it
    # as satisfying versioned dependencies. This is a problem for any
    # daily build version.
    return "%s.0dev0" % (version,)


setup(
    name='uservice-logging',
    version=get_version(),
    description='Utilities for logging for micro-services.',
    long_description=open('README.rst').read(),
    author='Canonical CI Engineering Tanuki Squad',
    author_email='canonical-ci-engineering@lists.launchpad.net',
    url='https://launchpad.net/uservice-logging',
    license='GPLv3',
    packages=find_packages(),
    test_suite='uservice_logging.tests',
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Programming Language :: Python :: 3 :: Only',
        'Topic :: Software Development'
    ]
)
